@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,16 +16,21 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core.client_options import ClientOptions
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.binaryauthorization_v1beta1.services.binauthz_management_service_v1_beta1 import (
     pagers,
 )
@@ -129,6 +134,42 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     from_service_account_json = from_service_account_file
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        return BinauthzManagementServiceV1Beta1Client.get_mtls_endpoint_and_cert_source(client_options)  # type: ignore
+
     @property
     def transport(self) -> BinauthzManagementServiceV1Beta1Transport:
         """Returns the transport used by the client instance.
@@ -194,10 +235,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def get_policy(
         self,
-        request: service.GetPolicyRequest = None,
+        request: Union[service.GetPolicyRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
@@ -215,8 +256,27 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         [policy][google.cloud.binaryauthorization.v1beta1.Policy] if the
         project does not have one.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            async def sample_get_policy():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.GetPolicyRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1beta1.types.GetPolicyRequest`):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.GetPolicyRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.GetPolicy][].
             name (:class:`str`):
@@ -235,12 +295,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Policy:
-                A [policy][google.cloud.binaryauthorization.v1beta1.Policy] for container
-                   image binary authorization.
+                A
+                [policy][google.cloud.binaryauthorization.v1beta1.Policy]
+                for Binary Authorization.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -281,17 +342,22 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def update_policy(
         self,
-        request: service.UpdatePolicyRequest = None,
+        request: Union[service.UpdatePolicyRequest, dict] = None,
         *,
         policy: resources.Policy = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
@@ -304,8 +370,31 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         Returns NOT_FOUND if the project does not exist,
         INVALID_ARGUMENT if the request is malformed.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            async def sample_update_policy():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1AsyncClient()
+
+                # Initialize request argument(s)
+                policy = binaryauthorization_v1beta1.Policy()
+                policy.default_admission_rule.evaluation_mode = "ALWAYS_DENY"
+                policy.default_admission_rule.enforcement_mode = "DRYRUN_AUDIT_LOG_ONLY"
+
+                request = binaryauthorization_v1beta1.UpdatePolicyRequest(
+                    policy=policy,
+                )
+
+                # Make the request
+                response = await client.update_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1beta1.types.UpdatePolicyRequest`):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.UpdatePolicyRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdatePolicy][].
             policy (:class:`google.cloud.binaryauthorization_v1beta1.types.Policy`):
@@ -327,12 +416,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Policy:
-                A [policy][google.cloud.binaryauthorization.v1beta1.Policy] for container
-                   image binary authorization.
+                A
+                [policy][google.cloud.binaryauthorization.v1beta1.Policy]
+                for Binary Authorization.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([policy])
         if request is not None and has_flattened_params:
@@ -375,19 +465,24 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def create_attestor(
         self,
-        request: service.CreateAttestorRequest = None,
+        request: Union[service.CreateAttestorRequest, dict] = None,
         *,
         parent: str = None,
         attestor_id: str = None,
         attestor: resources.Attestor = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -401,8 +496,33 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         already exists.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            async def sample_create_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1AsyncClient()
+
+                # Initialize request argument(s)
+                attestor = binaryauthorization_v1beta1.Attestor()
+                attestor.user_owned_drydock_note.note_reference = "note_reference_value"
+                attestor.name = "name_value"
+
+                request = binaryauthorization_v1beta1.CreateAttestorRequest(
+                    parent="parent_value",
+                    attestor_id="attestor_id_value",
+                    attestor=attestor,
+                )
+
+                # Make the request
+                response = await client.create_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1beta1.types.CreateAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.CreateAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.CreateAttestor][].
             parent (:class:`str`):
@@ -439,13 +559,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
-                   to container image artifacts. An existing attestor
-                   cannot be modified except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
+                   artifacts. An existing attestor cannot be modified
+                   except where indicated.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, attestor_id, attestor])
         if request is not None and has_flattened_params:
@@ -480,17 +600,22 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def get_attestor(
         self,
-        request: service.GetAttestorRequest = None,
+        request: Union[service.GetAttestorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -500,8 +625,27 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            async def sample_get_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.GetAttestorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = await client.get_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1beta1.types.GetAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.GetAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.GetAttestor][].
             name (:class:`str`):
@@ -520,13 +664,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
-                   to container image artifacts. An existing attestor
-                   cannot be modified except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
+                   artifacts. An existing attestor cannot be modified
+                   except where indicated.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -567,17 +711,22 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def update_attestor(
         self,
-        request: service.UpdateAttestorRequest = None,
+        request: Union[service.UpdateAttestorRequest, dict] = None,
         *,
         attestor: resources.Attestor = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -587,8 +736,31 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            async def sample_update_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1AsyncClient()
+
+                # Initialize request argument(s)
+                attestor = binaryauthorization_v1beta1.Attestor()
+                attestor.user_owned_drydock_note.note_reference = "note_reference_value"
+                attestor.name = "name_value"
+
+                request = binaryauthorization_v1beta1.UpdateAttestorRequest(
+                    attestor=attestor,
+                )
+
+                # Make the request
+                response = await client.update_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1beta1.types.UpdateAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.UpdateAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdateAttestor][].
             attestor (:class:`google.cloud.binaryauthorization_v1beta1.types.Attestor`):
@@ -610,13 +782,13 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
-                   to container image artifacts. An existing attestor
-                   cannot be modified except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
+                   artifacts. An existing attestor cannot be modified
+                   except where indicated.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([attestor])
         if request is not None and has_flattened_params:
@@ -659,17 +831,22 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     async def list_attestors(
         self,
-        request: service.ListAttestorsRequest = None,
+        request: Union[service.ListAttestorsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAttestorsAsyncPager:
@@ -677,8 +854,28 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         [attestors][google.cloud.binaryauthorization.v1beta1.Attestor].
         Returns INVALID_ARGUMENT if the project does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            async def sample_list_attestors():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.ListAttestorsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_attestors(request=request)
+
+                # Handle the response
+                async for response in page_result:
+                    print(response)
+
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1beta1.types.ListAttestorsRequest`):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.ListAttestorsRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.ListAttestors][].
             parent (:class:`str`):
@@ -706,7 +903,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -747,12 +944,20 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListAttestorsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -760,10 +965,10 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
     async def delete_attestor(
         self,
-        request: service.DeleteAttestorRequest = None,
+        request: Union[service.DeleteAttestorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -773,8 +978,24 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            async def sample_delete_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1AsyncClient()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.DeleteAttestorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                await client.delete_attestor(request=request)
+
         Args:
-            request (:class:`google.cloud.binaryauthorization_v1beta1.types.DeleteAttestorRequest`):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.DeleteAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.DeleteAttestor][].
             name (:class:`str`):
@@ -792,7 +1013,7 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -834,9 +1055,18 @@ class BinauthzManagementServiceV1Beta1AsyncClient:
 
         # Send the request.
         await rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
+    async def __aenter__(self):
+        return self
+
+    async def __aexit__(self, exc_type, exc, tb):
+        await self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
