@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -14,22 +14,26 @@
 # limitations under the License.
 #
 from collections import OrderedDict
-from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
-from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions as core_exceptions  # type: ignore
-from google.api_core import gapic_v1  # type: ignore
-from google.api_core import retry as retries  # type: ignore
+from google.api_core import client_options as client_options_lib
+from google.api_core import exceptions as core_exceptions
+from google.api_core import gapic_v1
+from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
+try:
+    OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
+except AttributeError:  # pragma: NO COVER
+    OptionalRetry = Union[retries.Retry, object]  # type: ignore
+
 from google.cloud.binaryauthorization_v1beta1.services.binauthz_management_service_v1_beta1 import (
     pagers,
 )
@@ -63,7 +67,8 @@ class BinauthzManagementServiceV1Beta1ClientMeta(type):
     ] = BinauthzManagementServiceV1Beta1GrpcAsyncIOTransport
 
     def get_transport_class(
-        cls, label: str = None,
+        cls,
+        label: str = None,
     ) -> Type[BinauthzManagementServiceV1Beta1Transport]:
         """Returns an appropriate transport class.
 
@@ -178,10 +183,14 @@ class BinauthzManagementServiceV1Beta1Client(
         return self._transport
 
     @staticmethod
-    def attestor_path(project: str, attestor: str,) -> str:
+    def attestor_path(
+        project: str,
+        attestor: str,
+    ) -> str:
         """Returns a fully-qualified attestor string."""
         return "projects/{project}/attestors/{attestor}".format(
-            project=project, attestor=attestor,
+            project=project,
+            attestor=attestor,
         )
 
     @staticmethod
@@ -191,9 +200,13 @@ class BinauthzManagementServiceV1Beta1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def policy_path(project: str,) -> str:
+    def policy_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified policy string."""
-        return "projects/{project}/policy".format(project=project,)
+        return "projects/{project}/policy".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_policy_path(path: str) -> Dict[str, str]:
@@ -202,7 +215,9 @@ class BinauthzManagementServiceV1Beta1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -215,9 +230,13 @@ class BinauthzManagementServiceV1Beta1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -226,9 +245,13 @@ class BinauthzManagementServiceV1Beta1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -237,9 +260,13 @@ class BinauthzManagementServiceV1Beta1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -248,10 +275,14 @@ class BinauthzManagementServiceV1Beta1Client(
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -260,6 +291,73 @@ class BinauthzManagementServiceV1Beta1Client(
         m = re.match(r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)$", path)
         return m.groupdict() if m else {}
 
+    @classmethod
+    def get_mtls_endpoint_and_cert_source(
+        cls, client_options: Optional[client_options_lib.ClientOptions] = None
+    ):
+        """Return the API endpoint and client cert source for mutual TLS.
+
+        The client cert source is determined in the following order:
+        (1) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is not "true", the
+        client cert source is None.
+        (2) if `client_options.client_cert_source` is provided, use the provided one; if the
+        default client cert source exists, use the default one; otherwise the client cert
+        source is None.
+
+        The API endpoint is determined in the following order:
+        (1) if `client_options.api_endpoint` if provided, use the provided one.
+        (2) if `GOOGLE_API_USE_CLIENT_CERTIFICATE` environment variable is "always", use the
+        default mTLS endpoint; if the environment variabel is "never", use the default API
+        endpoint; otherwise if client cert source exists, use the default mTLS endpoint, otherwise
+        use the default API endpoint.
+
+        More details can be found at https://google.aip.dev/auth/4114.
+
+        Args:
+            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+                client. Only the `api_endpoint` and `client_cert_source` properties may be used
+                in this method.
+
+        Returns:
+            Tuple[str, Callable[[], Tuple[bytes, bytes]]]: returns the API endpoint and the
+                client cert source to use.
+
+        Raises:
+            google.auth.exceptions.MutualTLSChannelError: If any errors happen.
+        """
+        if client_options is None:
+            client_options = client_options_lib.ClientOptions()
+        use_client_cert = os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false")
+        use_mtls_endpoint = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
+        if use_client_cert not in ("true", "false"):
+            raise ValueError(
+                "Environment variable `GOOGLE_API_USE_CLIENT_CERTIFICATE` must be either `true` or `false`"
+            )
+        if use_mtls_endpoint not in ("auto", "never", "always"):
+            raise MutualTLSChannelError(
+                "Environment variable `GOOGLE_API_USE_MTLS_ENDPOINT` must be `never`, `auto` or `always`"
+            )
+
+        # Figure out the client cert source to use.
+        client_cert_source = None
+        if use_client_cert == "true":
+            if client_options.client_cert_source:
+                client_cert_source = client_options.client_cert_source
+            elif mtls.has_default_client_cert_source():
+                client_cert_source = mtls.default_client_cert_source()
+
+        # Figure out which api endpoint to use.
+        if client_options.api_endpoint is not None:
+            api_endpoint = client_options.api_endpoint
+        elif use_mtls_endpoint == "always" or (
+            use_mtls_endpoint == "auto" and client_cert_source
+        ):
+            api_endpoint = cls.DEFAULT_MTLS_ENDPOINT
+        else:
+            api_endpoint = cls.DEFAULT_ENDPOINT
+
+        return api_endpoint, client_cert_source
+
     def __init__(
         self,
         *,
@@ -310,50 +408,22 @@ class BinauthzManagementServiceV1Beta1Client(
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
 
-        # Create SSL credentials for mutual TLS if needed.
-        use_client_cert = bool(
-            util.strtobool(os.getenv("GOOGLE_API_USE_CLIENT_CERTIFICATE", "false"))
+        api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
+            client_options
         )
 
-        client_cert_source_func = None
-        is_mtls = False
-        if use_client_cert:
-            if client_options.client_cert_source:
-                is_mtls = True
-                client_cert_source_func = client_options.client_cert_source
-            else:
-                is_mtls = mtls.has_default_client_cert_source()
-                if is_mtls:
-                    client_cert_source_func = mtls.default_client_cert_source()
-                else:
-                    client_cert_source_func = None
-
-        # Figure out which api endpoint to use.
-        if client_options.api_endpoint is not None:
-            api_endpoint = client_options.api_endpoint
-        else:
-            use_mtls_env = os.getenv("GOOGLE_API_USE_MTLS_ENDPOINT", "auto")
-            if use_mtls_env == "never":
-                api_endpoint = self.DEFAULT_ENDPOINT
-            elif use_mtls_env == "always":
-                api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-            elif use_mtls_env == "auto":
-                if is_mtls:
-                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
-                else:
-                    api_endpoint = self.DEFAULT_ENDPOINT
-            else:
-                raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
-                    "values: never, auto, always"
-                )
+        api_key_value = getattr(client_options, "api_key", None)
+        if api_key_value and credentials:
+            raise ValueError(
+                "client_options.api_key and credentials are mutually exclusive"
+            )
 
         # Save or instantiate the transport.
         # Ordinarily, we provide the transport, but allowing a custom transport
         # instance provides an extensibility point for unusual situations.
         if isinstance(transport, BinauthzManagementServiceV1Beta1Transport):
             # transport is a BinauthzManagementServiceV1Beta1Transport instance.
-            if credentials or client_options.credentials_file:
+            if credentials or client_options.credentials_file or api_key_value:
                 raise ValueError(
                     "When providing a transport instance, "
                     "provide its credentials directly."
@@ -365,6 +435,15 @@ class BinauthzManagementServiceV1Beta1Client(
                 )
             self._transport = transport
         else:
+            import google.auth._default  # type: ignore
+
+            if api_key_value and hasattr(
+                google.auth._default, "get_api_key_credentials"
+            ):
+                credentials = google.auth._default.get_api_key_credentials(
+                    api_key_value
+                )
+
             Transport = type(self).get_transport_class(transport)
             self._transport = Transport(
                 credentials=credentials,
@@ -374,18 +453,16 @@ class BinauthzManagementServiceV1Beta1Client(
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
-                always_use_jwt_access=(
-                    Transport == type(self).get_transport_class("grpc")
-                    or Transport == type(self).get_transport_class("grpc_asyncio")
-                ),
+                always_use_jwt_access=True,
+                api_audience=client_options.api_audience,
             )
 
     def get_policy(
         self,
-        request: service.GetPolicyRequest = None,
+        request: Union[service.GetPolicyRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
@@ -403,8 +480,27 @@ class BinauthzManagementServiceV1Beta1Client(
         [policy][google.cloud.binaryauthorization.v1beta1.Policy] if the
         project does not have one.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            def sample_get_policy():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.GetPolicyRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.binaryauthorization_v1beta1.types.GetPolicyRequest):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.GetPolicyRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.GetPolicy][].
             name (str):
@@ -423,12 +519,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Policy:
-                A [policy][google.cloud.binaryauthorization.v1beta1.Policy] for container
-                   image binary authorization.
+                A
+                [policy][google.cloud.binaryauthorization.v1beta1.Policy]
+                for Binary Authorization.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -459,17 +556,22 @@ class BinauthzManagementServiceV1Beta1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def update_policy(
         self,
-        request: service.UpdatePolicyRequest = None,
+        request: Union[service.UpdatePolicyRequest, dict] = None,
         *,
         policy: resources.Policy = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Policy:
@@ -482,8 +584,31 @@ class BinauthzManagementServiceV1Beta1Client(
         Returns NOT_FOUND if the project does not exist,
         INVALID_ARGUMENT if the request is malformed.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            def sample_update_policy():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                policy = binaryauthorization_v1beta1.Policy()
+                policy.default_admission_rule.evaluation_mode = "ALWAYS_DENY"
+                policy.default_admission_rule.enforcement_mode = "DRYRUN_AUDIT_LOG_ONLY"
+
+                request = binaryauthorization_v1beta1.UpdatePolicyRequest(
+                    policy=policy,
+                )
+
+                # Make the request
+                response = client.update_policy(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.binaryauthorization_v1beta1.types.UpdatePolicyRequest):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.UpdatePolicyRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdatePolicy][].
             policy (google.cloud.binaryauthorization_v1beta1.types.Policy):
@@ -505,12 +630,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Policy:
-                A [policy][google.cloud.binaryauthorization.v1beta1.Policy] for container
-                   image binary authorization.
+                A
+                [policy][google.cloud.binaryauthorization.v1beta1.Policy]
+                for Binary Authorization.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([policy])
         if request is not None and has_flattened_params:
@@ -543,19 +669,24 @@ class BinauthzManagementServiceV1Beta1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def create_attestor(
         self,
-        request: service.CreateAttestorRequest = None,
+        request: Union[service.CreateAttestorRequest, dict] = None,
         *,
         parent: str = None,
         attestor_id: str = None,
         attestor: resources.Attestor = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -569,8 +700,33 @@ class BinauthzManagementServiceV1Beta1Client(
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         already exists.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            def sample_create_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                attestor = binaryauthorization_v1beta1.Attestor()
+                attestor.user_owned_drydock_note.note_reference = "note_reference_value"
+                attestor.name = "name_value"
+
+                request = binaryauthorization_v1beta1.CreateAttestorRequest(
+                    parent="parent_value",
+                    attestor_id="attestor_id_value",
+                    attestor=attestor,
+                )
+
+                # Make the request
+                response = client.create_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.binaryauthorization_v1beta1.types.CreateAttestorRequest):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.CreateAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.CreateAttestor][].
             parent (str):
@@ -607,13 +763,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
-                   to container image artifacts. An existing attestor
-                   cannot be modified except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
+                   artifacts. An existing attestor cannot be modified
+                   except where indicated.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent, attestor_id, attestor])
         if request is not None and has_flattened_params:
@@ -648,17 +804,22 @@ class BinauthzManagementServiceV1Beta1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def get_attestor(
         self,
-        request: service.GetAttestorRequest = None,
+        request: Union[service.GetAttestorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -668,8 +829,27 @@ class BinauthzManagementServiceV1Beta1Client(
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            def sample_get_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.GetAttestorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                response = client.get_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.binaryauthorization_v1beta1.types.GetAttestorRequest):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.GetAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.GetAttestor][].
             name (str):
@@ -688,13 +868,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
-                   to container image artifacts. An existing attestor
-                   cannot be modified except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
+                   artifacts. An existing attestor cannot be modified
+                   except where indicated.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -725,17 +905,22 @@ class BinauthzManagementServiceV1Beta1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def update_attestor(
         self,
-        request: service.UpdateAttestorRequest = None,
+        request: Union[service.UpdateAttestorRequest, dict] = None,
         *,
         attestor: resources.Attestor = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> resources.Attestor:
@@ -745,8 +930,31 @@ class BinauthzManagementServiceV1Beta1Client(
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            def sample_update_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                attestor = binaryauthorization_v1beta1.Attestor()
+                attestor.user_owned_drydock_note.note_reference = "note_reference_value"
+                attestor.name = "name_value"
+
+                request = binaryauthorization_v1beta1.UpdateAttestorRequest(
+                    attestor=attestor,
+                )
+
+                # Make the request
+                response = client.update_attestor(request=request)
+
+                # Handle the response
+                print(response)
+
         Args:
-            request (google.cloud.binaryauthorization_v1beta1.types.UpdateAttestorRequest):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.UpdateAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.UpdateAttestor][].
             attestor (google.cloud.binaryauthorization_v1beta1.types.Attestor):
@@ -768,13 +976,13 @@ class BinauthzManagementServiceV1Beta1Client(
 
         Returns:
             google.cloud.binaryauthorization_v1beta1.types.Attestor:
-                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests
-                   to container image artifacts. An existing attestor
-                   cannot be modified except where indicated.
+                An [attestor][google.cloud.binaryauthorization.v1beta1.Attestor] that attests to container image
+                   artifacts. An existing attestor cannot be modified
+                   except where indicated.
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([attestor])
         if request is not None and has_flattened_params:
@@ -807,17 +1015,22 @@ class BinauthzManagementServiceV1Beta1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
 
     def list_attestors(
         self,
-        request: service.ListAttestorsRequest = None,
+        request: Union[service.ListAttestorsRequest, dict] = None,
         *,
         parent: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> pagers.ListAttestorsPager:
@@ -825,8 +1038,28 @@ class BinauthzManagementServiceV1Beta1Client(
         [attestors][google.cloud.binaryauthorization.v1beta1.Attestor].
         Returns INVALID_ARGUMENT if the project does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            def sample_list_attestors():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.ListAttestorsRequest(
+                    parent="parent_value",
+                )
+
+                # Make the request
+                page_result = client.list_attestors(request=request)
+
+                # Handle the response
+                for response in page_result:
+                    print(response)
+
         Args:
-            request (google.cloud.binaryauthorization_v1beta1.types.ListAttestorsRequest):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.ListAttestorsRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.ListAttestors][].
             parent (str):
@@ -854,7 +1087,7 @@ class BinauthzManagementServiceV1Beta1Client(
 
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([parent])
         if request is not None and has_flattened_params:
@@ -885,12 +1118,20 @@ class BinauthzManagementServiceV1Beta1Client(
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListAttestorsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -898,10 +1139,10 @@ class BinauthzManagementServiceV1Beta1Client(
 
     def delete_attestor(
         self,
-        request: service.DeleteAttestorRequest = None,
+        request: Union[service.DeleteAttestorRequest, dict] = None,
         *,
         name: str = None,
-        retry: retries.Retry = gapic_v1.method.DEFAULT,
+        retry: OptionalRetry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> None:
@@ -911,8 +1152,24 @@ class BinauthzManagementServiceV1Beta1Client(
         [attestor][google.cloud.binaryauthorization.v1beta1.Attestor]
         does not exist.
 
+        .. code-block:: python
+
+            from google.cloud import binaryauthorization_v1beta1
+
+            def sample_delete_attestor():
+                # Create a client
+                client = binaryauthorization_v1beta1.BinauthzManagementServiceV1Beta1Client()
+
+                # Initialize request argument(s)
+                request = binaryauthorization_v1beta1.DeleteAttestorRequest(
+                    name="name_value",
+                )
+
+                # Make the request
+                client.delete_attestor(request=request)
+
         Args:
-            request (google.cloud.binaryauthorization_v1beta1.types.DeleteAttestorRequest):
+            request (Union[google.cloud.binaryauthorization_v1beta1.types.DeleteAttestorRequest, dict]):
                 The request object. Request message for
                 [BinauthzManagementService.DeleteAttestor][].
             name (str):
@@ -930,7 +1187,7 @@ class BinauthzManagementServiceV1Beta1Client(
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-        # Sanity check: If we got a request object, we should *not* have
+        # Quick check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
         has_flattened_params = any([name])
         if request is not None and has_flattened_params:
@@ -962,9 +1219,25 @@ class BinauthzManagementServiceV1Beta1Client(
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        """Releases underlying transport's resources.
+
+        .. warning::
+            ONLY use as a context manager if the transport is NOT shared
+            with other clients! Exiting the with block will CLOSE the transport
+            and may cause errors in other clients!
+        """
+        self.transport.close()
+
 
 try:
     DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
