@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -57,21 +57,21 @@ class Policy(proto.Message):
             permitted. This feature is typically used to
             exclude Google or third-party infrastructure
             images from Binary Authorization policies.
-        cluster_admission_rules (Sequence[google.cloud.binaryauthorization_v1beta1.types.Policy.ClusterAdmissionRulesEntry]):
+        cluster_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-cluster admission rules. Cluster spec format:
             ``location.clusterId``. There can be at most one admission
             rule per cluster spec. A ``location`` is either a compute
             zone (e.g. us-central1-a) or a region (e.g. us-central1).
             For ``clusterId`` syntax restrictions see
             https://cloud.google.com/container-engine/reference/rest/v1/projects.zones.clusters.
-        kubernetes_namespace_admission_rules (Sequence[google.cloud.binaryauthorization_v1beta1.types.Policy.KubernetesNamespaceAdmissionRulesEntry]):
+        kubernetes_namespace_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-kubernetes-namespace admission rules. K8s
             namespace spec format: ``[a-z.-]+``, e.g. ``some-namespace``
-        kubernetes_service_account_admission_rules (Sequence[google.cloud.binaryauthorization_v1beta1.types.Policy.KubernetesServiceAccountAdmissionRulesEntry]):
+        kubernetes_service_account_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-kubernetes-service-account admission rules.
             Service account spec format: ``namespace:serviceaccount``.
             e.g. ``test-ns:default``
-        istio_service_identity_admission_rules (Sequence[google.cloud.binaryauthorization_v1beta1.types.Policy.IstioServiceIdentityAdmissionRulesEntry]):
+        istio_service_identity_admission_rules (Mapping[str, google.cloud.binaryauthorization_v1beta1.types.AdmissionRule]):
             Optional. Per-istio-service-identity admission rules. Istio
             service identity spec format:
             ``spiffe://<domain>/ns/<namespace>/sa/<serviceaccount>`` or
@@ -93,30 +93,58 @@ class Policy(proto.Message):
         ENABLE = 1
         DISABLE = 2
 
-    name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=6,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     global_policy_evaluation_mode = proto.Field(
-        proto.ENUM, number=7, enum=GlobalPolicyEvaluationMode,
+        proto.ENUM,
+        number=7,
+        enum=GlobalPolicyEvaluationMode,
     )
     admission_whitelist_patterns = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="AdmissionWhitelistPattern",
+        proto.MESSAGE,
+        number=2,
+        message="AdmissionWhitelistPattern",
     )
     cluster_admission_rules = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=3, message="AdmissionRule",
+        proto.STRING,
+        proto.MESSAGE,
+        number=3,
+        message="AdmissionRule",
     )
     kubernetes_namespace_admission_rules = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=10, message="AdmissionRule",
+        proto.STRING,
+        proto.MESSAGE,
+        number=10,
+        message="AdmissionRule",
     )
     kubernetes_service_account_admission_rules = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=8, message="AdmissionRule",
+        proto.STRING,
+        proto.MESSAGE,
+        number=8,
+        message="AdmissionRule",
     )
     istio_service_identity_admission_rules = proto.MapField(
-        proto.STRING, proto.MESSAGE, number=9, message="AdmissionRule",
+        proto.STRING,
+        proto.MESSAGE,
+        number=9,
+        message="AdmissionRule",
     )
     default_admission_rule = proto.Field(
-        proto.MESSAGE, number=4, message="AdmissionRule",
+        proto.MESSAGE,
+        number=4,
+        message="AdmissionRule",
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=5,
+        message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
 
 
 class AdmissionWhitelistPattern(proto.Message):
@@ -137,7 +165,10 @@ class AdmissionWhitelistPattern(proto.Message):
             i.e., ``gcr.io/nginx**`` matches ``gcr.io/nginx/image``.
     """
 
-    name_pattern = proto.Field(proto.STRING, number=1,)
+    name_pattern = proto.Field(
+        proto.STRING,
+        number=1,
+    )
 
 
 class AdmissionRule(proto.Message):
@@ -189,9 +220,20 @@ class AdmissionRule(proto.Message):
         ENFORCED_BLOCK_AND_AUDIT_LOG = 1
         DRYRUN_AUDIT_LOG_ONLY = 2
 
-    evaluation_mode = proto.Field(proto.ENUM, number=1, enum=EvaluationMode,)
-    require_attestations_by = proto.RepeatedField(proto.STRING, number=2,)
-    enforcement_mode = proto.Field(proto.ENUM, number=3, enum=EnforcementMode,)
+    evaluation_mode = proto.Field(
+        proto.ENUM,
+        number=1,
+        enum=EvaluationMode,
+    )
+    require_attestations_by = proto.RepeatedField(
+        proto.STRING,
+        number=2,
+    )
+    enforcement_mode = proto.Field(
+        proto.ENUM,
+        number=3,
+        enum=EnforcementMode,
+    )
 
 
 class Attestor(proto.Message):
@@ -219,12 +261,25 @@ class Attestor(proto.Message):
             updated.
     """
 
-    name = proto.Field(proto.STRING, number=1,)
-    description = proto.Field(proto.STRING, number=6,)
+    name = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    description = proto.Field(
+        proto.STRING,
+        number=6,
+    )
     user_owned_drydock_note = proto.Field(
-        proto.MESSAGE, number=3, oneof="attestor_type", message="UserOwnedDrydockNote",
+        proto.MESSAGE,
+        number=3,
+        oneof="attestor_type",
+        message="UserOwnedDrydockNote",
+    )
+    update_time = proto.Field(
+        proto.MESSAGE,
+        number=4,
+        message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(proto.MESSAGE, number=4, message=timestamp_pb2.Timestamp,)
 
 
 class UserOwnedDrydockNote(proto.Message):
@@ -268,11 +323,19 @@ class UserOwnedDrydockNote(proto.Message):
             email based on a different naming pattern.
     """
 
-    note_reference = proto.Field(proto.STRING, number=1,)
+    note_reference = proto.Field(
+        proto.STRING,
+        number=1,
+    )
     public_keys = proto.RepeatedField(
-        proto.MESSAGE, number=2, message="AttestorPublicKey",
+        proto.MESSAGE,
+        number=2,
+        message="AttestorPublicKey",
+    )
+    delegation_service_account_email = proto.Field(
+        proto.STRING,
+        number=3,
     )
-    delegation_service_account_email = proto.Field(proto.STRING, number=3,)
 
 
 class PkixPublicKey(proto.Message):
@@ -319,8 +382,15 @@ class PkixPublicKey(proto.Message):
         ECDSA_P521_SHA512 = 11
         EC_SIGN_P521_SHA512 = 11
 
-    public_key_pem = proto.Field(proto.STRING, number=1,)
-    signature_algorithm = proto.Field(proto.ENUM, number=2, enum=SignatureAlgorithm,)
+    public_key_pem = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    signature_algorithm = proto.Field(
+        proto.ENUM,
+        number=2,
+        enum=SignatureAlgorithm,
+    )
 
 
 class AttestorPublicKey(proto.Message):
@@ -370,13 +440,24 @@ class AttestorPublicKey(proto.Message):
             This field is a member of `oneof`_ ``public_key``.
     """
 
-    comment = proto.Field(proto.STRING, number=1,)
-    id = proto.Field(proto.STRING, number=2,)
+    comment = proto.Field(
+        proto.STRING,
+        number=1,
+    )
+    id = proto.Field(
+        proto.STRING,
+        number=2,
+    )
     ascii_armored_pgp_public_key = proto.Field(
-        proto.STRING, number=3, oneof="public_key",
+        proto.STRING,
+        number=3,
+        oneof="public_key",
     )
     pkix_public_key = proto.Field(
-        proto.MESSAGE, number=5, oneof="public_key", message="PkixPublicKey",
+        proto.MESSAGE,
+        number=5,
+        oneof="public_key",
+        message="PkixPublicKey",
     )
 
 
